@@ -75,6 +75,9 @@ func main() {
 	configRules = append(configRules, rules.GitHubRefresh())
 	configRules = append(configRules, rules.Gitlab())
 	configRules = append(configRules, rules.GitterAccessToken())
+	configRules = append(configRules, rules.GrafanaApiKey())
+	configRules = append(configRules, rules.GrafanaCloudApiToken())
+	configRules = append(configRules, rules.GrafanaServiceAccountToken())
 	configRules = append(configRules, rules.Hashicorp())
 	configRules = append(configRules, rules.Heroku())
 	configRules = append(configRules, rules.HubSpot())
@@ -112,11 +115,13 @@ func main() {
 	configRules = append(configRules, rules.PlanetScaleAPIToken())
 	configRules = append(configRules, rules.PlanetScaleOAuthToken())
 	configRules = append(configRules, rules.PostManAPI())
+	configRules = append(configRules, rules.Prefect())
 	configRules = append(configRules, rules.PrivateKey())
 	configRules = append(configRules, rules.PulumiAPIToken())
 	configRules = append(configRules, rules.PyPiUploadToken())
-	configRules = append(configRules, rules.RubyGemsAPIToken())
 	configRules = append(configRules, rules.RapidAPIAccessToken())
+	configRules = append(configRules, rules.ReadMe())
+	configRules = append(configRules, rules.RubyGemsAPIToken())
 	configRules = append(configRules, rules.SendbirdAccessID())
 	configRules = append(configRules, rules.SendbirdAccessToken())
 	configRules = append(configRules, rules.SendGridAPIToken())
